==> react-hooks-1.19.0.tgz: package/lib/useOnScreen/index.js <==
import { useEffect, useRef, useState } from 'react';
import PropTypes from 'prop-types';
export function useNearScreen(_temp) {
  var _ref = _temp === void 0 ? {} : _temp,
      _ref$offset = _ref.offset,
      offset = _ref$offset === void 0 ? '200px' : _ref$offset;

  return useOnScreen({
    once: true,
    offset: offset
  });
}
export default function useOnScreen(_temp2) {
  var _ref2 = _temp2 === void 0 ? {} : _temp2,
      ref = _ref2.ref,
      _ref2$once = _ref2.once,
      once = _ref2$once === void 0 ? true : _ref2$once,
      _ref2$offset = _ref2.offset,
      offset = _ref2$offset === void 0 ? '0px' : _ref2$offset;

  // State and setter for storing whether element is visible or not
  var _useState = useState(false),
      isIntersecting = _useState[0],
      setIntersecting = _useState[1];

  var outerRef = useRef();
  useEffect(function () {
    var usableRef = ref || outerRef;

    var _ref3 = usableRef || {},
        current = _ref3.current;

    if (!current) return;
    var observer;
    (window.IntersectionObserver ? Promise.resolve() : import('intersection-observer')).then(function () {
      observer = new window.IntersectionObserver(function (_ref4) {
        var entry = _ref4[0];
        // Update our state when observer callback fires
        setIntersecting(entry.isIntersecting);

        if (entry.isIntersecting) {
          // Unobserve now if we've set once option
          once && observer && observer.unobserve(current);
        }
      }, {
        rootMargin: offset
      });
      current && observer.observe(current);
    });
    return function () {
      observer && observer.unobserve(current);
    };
  }, [offset, once, ref]);
  return [isIntersecting, outerRef];
}
useOnScreen.displayName = 'HookUseOnScreen';
useOnScreen.propTypes = {
  ref: PropTypes.element,
  rootMargin: PropTypes.string
};

==> react-hooks-1.22.0.tgz: package/lib/useOnScreen/index.js <==
import { useEffect, useRef, useState } from 'react';
import PropTypes from 'prop-types';
export function useNearScreen(_temp) {
  var _ref = _temp === void 0 ? {} : _temp,
      _ref$initialValue = _ref.initialValue,
      initialValue = _ref$initialValue === void 0 ? false : _ref$initialValue,
      _ref$offset = _ref.offset,
      offset = _ref$offset === void 0 ? '200px' : _ref$offset;

  return useOnScreen({
    once: true,
    offset: offset,
    initialValue: initialValue
  });
}
export default function useOnScreen(_temp2) {
  var _ref2 = _temp2 === void 0 ? {} : _temp2,
      _ref2$initialValue = _ref2.initialValue,
      initialValue = _ref2$initialValue === void 0 ? false : _ref2$initialValue,
      _ref2$offset = _ref2.offset,
      offset = _ref2$offset === void 0 ? '0px' : _ref2$offset,
      _ref2$once = _ref2.once,
      once = _ref2$once === void 0 ? true : _ref2$once,
      ref = _ref2.ref;

  // State and setter for storing whether element is visible or not
  var _useState = useState(initialValue),
      isIntersecting = _useState[0],
      setIntersecting = _useState[1];

  var outerRef = useRef();
  useEffect(function () {
    var usableRef = ref || outerRef;

    var _ref3 = usableRef || {},
        current = _ref3.current;

    if (!current) return;
    var observer;
    (window.IntersectionObserver ? Promise.resolve() : import('intersection-observer')).then(function () {
      observer = new window.IntersectionObserver(function (_ref4) {
        var entry = _ref4[0];
        // Update our state when observer callback fires
        setIntersecting(entry.isIntersecting);

        if (entry.isIntersecting) {
          // Unobserve now if we've set once option
          once && observer && observer.unobserve(current);
        }
      }, {
        rootMargin: offset
      });
      current && observer.observe(current);
    });
    return function () {
      observer && observer.unobserve(current);
    };
  }, [offset, once, ref]);
  return [isIntersecting, outerRef];
}
useOnScreen.displayName = 'HookUseOnScreen';
useOnScreen.propTypes = {
  ref: PropTypes.element,
  rootMargin: PropTypes.string
};
